@@ -47,9 +47,13 @@ class TestSystemConfiguration(TestCase):
         self.assertTrue(isinstance(err, SystemConfiguration.CFErrorRef))
 
     def testFunctions(self):
-
         err = SystemConfiguration.SCError()
         self.assertIsInstance(err, int)
 
         err = SystemConfiguration.SCErrorString(SystemConfiguration.kSCStatusNoLink)
         self.assertIsInstance(err, bytes)
+
+
+class TestCallableMetadata(TestCase):
+    def test_callable_metadata_is_sane(self):
+        self.assertCallableMetadataIsSane(SystemConfiguration)
